@@ -17,21 +17,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
 #ifndef DBUS_MARSHAL_RECURSIVE_H
 #define DBUS_MARSHAL_RECURSIVE_H
 
-#include <config.h>
 #include <dbus/dbus-protocol.h>
 #include <dbus/dbus-list.h>
 
-#ifndef PACKAGE
-#error "config.h not included here"
-#endif
-
 typedef struct DBusTypeReader      DBusTypeReader;
 typedef struct DBusTypeWriter      DBusTypeWriter;
 typedef struct DBusTypeReaderClass DBusTypeReaderClass;
@@ -134,8 +129,6 @@ dbus_bool_t _dbus_type_reader_set_basic                 (DBusTypeReader        *
                                                          const DBusTypeReader  *realign_root);
 dbus_bool_t _dbus_type_reader_delete                    (DBusTypeReader        *reader,
                                                          const DBusTypeReader  *realign_root);
-dbus_bool_t _dbus_type_reader_greater_than              (const DBusTypeReader  *lhs,
-                                                         const DBusTypeReader  *rhs);
 
 dbus_bool_t _dbus_type_reader_equal_values              (const DBusTypeReader *lhs,
                                                          const DBusTypeReader *rhs);
@@ -183,14 +176,6 @@ dbus_bool_t _dbus_type_writer_append_array         (DBusTypeWriter        *write
                                                     DBusTypeWriter        *sub);
 dbus_bool_t _dbus_type_writer_write_reader         (DBusTypeWriter        *writer,
                                                     DBusTypeReader        *reader);
-dbus_bool_t _dbus_type_writer_write_reader_partial (DBusTypeWriter        *writer,
-                                                    DBusTypeReader        *reader,
-                                                    const DBusTypeReader  *start_after,
-                                                    int                    start_after_new_pos,
-                                                    int                    start_after_new_len,
-                                                    DBusList             **fixups);
-void        _dbus_type_writer_set_enabled          (DBusTypeWriter        *writer,
-                                                    dbus_bool_t            enabled);
 
 
 #endif /* DBUS_MARSHAL_RECURSIVE_H */
